;; Generated package description from clojure-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "clojure-mode" "5.23.0.0.20260708.5" "Major mode for Clojure code" '((emacs "27.1")) :commit "d7c849137fb130110be6ae9cd8f41f230ac06d72" :maintainer '("Bozhidar Batsov" . "bozhidar@batsov.dev") :keywords '("languages" "clojure" "clojurescript" "lisp") :url "https://github.com/clojure-emacs/clojure-mode")
