((nil
  (bug-reference-url-format . "https://github.com/clojure-emacs/clojure-mode/issues/%s")
  (indent-tabs-mode . nil)
  (fill-column . 80)
  (checkdoc-arguments-in-order-flag))
 (emacs-lisp-mode
  (bug-reference-bug-regexp . "#\\(?2:[[:digit:]]+\\)")))
